@@ -78,9 +78,12 @@ namespace Oxygen
 
         ui.setupUi( this );
 
-        _progressBar1 = new ProgressBar( this, ui.progressBar, ui.checkBox );
-        _progressBar2 = new ProgressBar( this, ui.progressBar_2, ui.checkBox_2 );
-        ui.checkBox_2->setChecked( true );
+        _horizontalProgressBar = new ProgressBar( this, ui.horizontalProgressBar, ui.animateProgressBarCheckBox );
+        _verticalProgressBar = new ProgressBar( this, ui.verticalProgressBar, ui.animateProgressBarCheckBox );
+
+        connect( ui.invertProgressBarCheckBox, SIGNAL(toggled(bool)), _horizontalProgressBar, SLOT(toggleInvertedAppearance(bool)));
+        connect( ui.invertProgressBarCheckBox, SIGNAL(toggled(bool)), _verticalProgressBar, SLOT(toggleInvertedAppearance(bool)));
+        connect( ui.tickPositionComboBox, SIGNAL(currentIndexChanged(int)), SLOT(updateTickPosition(int)) );
 
         connect( ui.horizontalSlider, SIGNAL(valueChanged(int)), SLOT(updateSliders(int)) );
         connect( ui.horizontalScrollBar, SIGNAL(valueChanged(int)), SLOT(updateSliders(int)) );
@@ -122,12 +125,11 @@ namespace Oxygen
         if( _locked ) return;
 
         _locked = true;
-        _progressBar1->setValue( value );
-        _progressBar2->setValue( value );
+        _horizontalProgressBar->setValue( value );
+        _verticalProgressBar->setValue( value );
 
         ui.horizontalSlider->setValue( value );
         ui.verticalSlider->setValue( value );
-        ui.progressBar_3->setValue( value );
         ui.horizontalScrollBar->setValue( value );
         ui.verticalScrollBar->setValue( value );
         ui.dial->setValue( value );
@@ -135,4 +137,12 @@ namespace Oxygen
         _locked = false;
 
     }
+
+    //_____________________________________________________________
+    void SliderDemoWidget::updateTickPosition( int value )
+    {
+        ui.horizontalSlider->setTickPosition( QSlider::TickPosition( value ) );
+        ui.verticalSlider->setTickPosition( QSlider::TickPosition( value ) );
+        ui.dial->setNotchesVisible( value > 0 );
+    }
 }
